# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: obsolete.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import sequence_and_updates_pb2 as sequence__and__updates__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='obsolete.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0eobsolete.proto\x12\x06\x64ialog\x1a\x15scalapb/scalapb.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1asequence_and_updates.proto\"\x9c\x02\n\x0cObsoletePeer\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32%.dialog.ObsoletePeer.ObsoletePeerType\x12\n\n\x02id\x18\x02 \x01(\x05\x12+\n\x05strId\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x13\n\x0b\x61\x63\x63\x65ss_hash\x18\x04 \x01(\x03\"\x88\x01\n\x10ObsoletePeerType\x12\x1d\n\x19OBSOLETE_PEERTYPE_UNKNOWN\x10\x00\x12\x1d\n\x19OBSOLETE_PEERTYPE_PRIVATE\x10\x01\x12\x1b\n\x17OBSOLETE_PEERTYPE_GROUP\x10\x02\x12\x19\n\x15OBSOLETE_PEERTYPE_SIP\x10\x04\"I\n\x0fObsoleteOutPeer\x12\"\n\x04peer\x18\x01 \x01(\x0b\x32\x14.dialog.ObsoletePeer\x12\x12\n\naccessHash\x18\x02 \x01(\x03\"8\n\x11ObsoletePeersList\x12#\n\x05peers\x18\x01 \x03(\x0b\x32\x14.dialog.ObsoletePeer\"k\n\x1cObsoleteGetDifferenceCommand\x12(\n\x03seq\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\r\n\x05state\x18\x02 \x01(\x0c\x12\x12\n\nconfigHash\x18\x03 \x01(\x03\"v\n\x14ObsoleteSeqUpdateBox\x12\x0b\n\x03seq\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\x0c\x12\x35\n\x0eobsoleteUpdate\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.BytesValueH\x00\x42\x0b\n\tupdatebox\"\xda\x16\n\x15ObsoleteWeakUpdateBox\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\x03\x12\x44\n\x06typing\x18\x02 \x01(\x0b\x32\x32.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateTypingH\x00\x12P\n\x0cuserLastSeen\x18\x03 \x01(\x0b\x32\x38.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateUserLastSeenH\x00\x12N\n\x0bgroupOnline\x18\x04 \x01(\x0b\x32\x37.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateGroupOnlineH\x00\x12Q\n\nbusMessage\x18\x05 \x01(\x0b\x32;.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusMessageH\x00\x12\x61\n\x12\x62usDeviceConnected\x18\x06 \x01(\x0b\x32\x43.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceConnectedH\x00\x12g\n\x15\x62usDeviceDisconnected\x18\x07 \x01(\x0b\x32\x46.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceDisconnectedH\x00\x12S\n\x0b\x62usDisposed\x18\x08 \x01(\x0b\x32<.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDisposedH\x00\x12S\n\x0b\x66orceReload\x18\t \x01(\x0b\x32<.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadStateH\x00\x12P\n\x0cincomingCall\x18\n \x01(\x0b\x32\x38.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateIncomingCallH\x00\x12N\n\x0b\x63\x61llHandled\x18\x0b \x01(\x0b\x32\x37.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallHandledH\x00\x12P\n\x0c\x63\x61llDisposed\x18\x0c \x01(\x0b\x32\x38.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallDisposedH\x00\x12+\n\nupdate_any\x18\r \x01(\x0b\x32\x17.dialog.UpdateSeqUpdate\x1a\x86\x01\n\x14ObsoleteUpdateTyping\x12\"\n\x04peer\x18\x01 \x01(\x0b\x32\x14.dialog.ObsoletePeer\x12\x0e\n\x06userId\x18\x02 \x01(\x05\x12(\n\x04type\x18\x03 \x01(\x0e\x32\x1a.dialog.ObsoleteTypingType\x12\x10\n\x08isTyping\x18\x04 \x01(\x08\x1a\x7f\n\x1aObsoleteUpdateUserLastSeen\x12\x0e\n\x06userId\x18\x01 \x01(\x05\x12\x13\n\x0b\x65pochMillis\x18\x02 \x01(\x03\x12\x12\n\ndeviceType\x18\x03 \x01(\x05\x12\x16\n\x0e\x64\x65viceCategory\x18\x04 \x01(\t\x12\x10\n\x08isOnline\x18\x05 \x01(\x08\x1aJ\n\x19ObsoleteUpdateGroupOnline\x12\x0f\n\x07groupId\x18\x01 \x01(\x05\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\r\n\x05\x63lock\x18\x03 \x01(\x03\x1a\xa3\x01\n\x1dObsoleteUpdateEventBusMessage\x12\r\n\x05\x62usId\x18\x01 \x01(\t\x12-\n\x08senderId\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x33\n\x0esenderDeviceId\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x0f\n\x07message\x18\x04 \x01(\x0c\x1au\n%ObsoleteUpdateEventBusDeviceConnected\x12\r\n\x05\x62usId\x18\x01 \x01(\t\x12+\n\x06userId\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x10\n\x08\x64\x65viceId\x18\x03 \x01(\x03\x1ax\n(ObsoleteUpdateEventBusDeviceDisconnected\x12\r\n\x05\x62usId\x18\x01 \x01(\t\x12+\n\x06userId\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x10\n\x08\x64\x65viceId\x18\x03 \x01(\x03\x1a/\n\x1eObsoleteUpdateEventBusDisposed\x12\r\n\x05\x62usId\x18\x01 \x01(\t\x1a\xef\x01\n\x1aObsoleteUpdateIncomingCall\x12\x0e\n\x06\x63\x61llId\x18\x01 \x01(\x03\x12\r\n\x05\x62usId\x18\x02 \x01(\t\x12\"\n\x04peer\x18\x03 \x01(\x0b\x32\x14.dialog.ObsoletePeer\x12\x31\n\x0b\x64isplayName\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0c\x61ttemptIndex\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12(\n\x07outPeer\x18\x06 \x01(\x0b\x32\x17.dialog.ObsoleteOutPeer\x1a^\n\x19ObsoleteUpdateCallHandled\x12\x0e\n\x06\x63\x61llId\x18\x01 \x01(\x03\x12\x31\n\x0c\x61ttemptIndex\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x1a\x9c\x03\n\x1aObsoleteUpdateCallDisposed\x12\x0e\n\x06\x63\x61llId\x18\x01 \x01(\x03\x12\x31\n\x0c\x61ttemptIndex\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12_\n\x06reason\x18\x03 \x01(\x0e\x32O.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallDisposed.ObsoleteDisposalReason\"\xd9\x01\n\x16ObsoleteDisposalReason\x12$\n OBSOLETE_DISPOSAL_REASON_UNKNOWN\x10\x00\x12%\n!OBSOLETE_DISPOSAL_REASON_REJECTED\x10\x01\x12!\n\x1dOBSOLETE_DISPOSAL_REASON_BUSY\x10\x02\x12\"\n\x1eOBSOLETE_DISPOSAL_REASON_ENDED\x10\x03\x12+\n\'OBSOLETE_DISPOSAL_REASON_ANSWER_TIMEOUT\x10\x04\x1a\xc4\x02\n\x1eObsoleteUpdateForceReloadState\x12\x65\n\x06\x66ields\x18\x01 \x03(\x0b\x32U.dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState.ObsoleteForceReloadField\x1a\xba\x01\n\x18ObsoleteForceReloadField\x12/\n\rreloadDialogs\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x30\n\x0ereloadContacts\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x32\n\rreloadHistory\x18\x03 \x01(\x0b\x32\x19.dialog.ObsoletePeersListH\x00\x42\x07\n\x05\x66ieldB\x0b\n\tupdatebox\"X\n\x15ObsoleteServiceUpdate\x12\x35\n\x0eobsoleteUpdate\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValueH\x00\x42\x08\n\x06update\"\xeb\x05\n\x19ObsoleteWeakUpdateCommand\x12\x37\n\x12subscribeToOnlines\x18\x01 \x01(\x0b\x32\x19.dialog.ObsoletePeersListH\x00\x12;\n\x16unsubscribeFromOnlines\x18\x02 \x01(\x0b\x32\x19.dialog.ObsoletePeersListH\x00\x12\x39\n\x17\x64ropOnlineSubscriptions\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x46\n\x08myTyping\x18\x07 \x01(\x0b\x32\x32.dialog.ObsoleteWeakUpdateCommand.ObsoleteMyTypingH\x00\x12\x37\n\x12subscribeToTypings\x18\x08 \x01(\x0b\x32\x19.dialog.ObsoletePeersListH\x00\x12;\n\x16unsubscribeFromTypings\x18\t \x01(\x0b\x32\x19.dialog.ObsoletePeersListH\x00\x12\x39\n\x17\x64ropTypingSubscriptions\x18\n \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12<\n\x1asubscribeToEventBusUpdates\x18\x0b \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x46\n\x08myOnline\x18\x0c \x01(\x0b\x32\x32.dialog.ObsoleteWeakUpdateCommand.ObsoleteMyOnlineH\x00\x1ao\n\x10ObsoleteMyTyping\x12\"\n\x04peer\x18\x01 \x01(\x0b\x32\x14.dialog.ObsoletePeer\x12(\n\x04type\x18\x02 \x01(\x0e\x32\x1a.dialog.ObsoleteTypingType\x12\r\n\x05start\x18\x03 \x01(\x08\x1a\"\n\x10ObsoleteMyOnline\x12\x0e\n\x06online\x18\x01 \x01(\x08\x42\t\n\x07\x63ommand*S\n\x12ObsoleteTypingType\x12\x1f\n\x1bOBSOLETE_TYPINGTYPE_UNKNOWN\x10\x00\x12\x1c\n\x18OBSOLETE_TYPINGTYPE_TEXT\x10\x01\x32\xe5\x02\n\x08Obsolete\x12k\n\x08Obsolete\x12\x1b.google.protobuf.BytesValue\x1a\x1b.google.protobuf.BytesValue\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/grpc/Obsolete/Obsolete:\x01*\x12m\n\nSeqUpdates\x12\x16.google.protobuf.Empty\x1a\x1c.dialog.ObsoleteSeqUpdateBox\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v1/grpc/Obsolete/SeqUpdates:\x01*0\x01\x12}\n\x0bWeakUpdates\x12!.dialog.ObsoleteWeakUpdateCommand\x1a\x1d.dialog.ObsoleteWeakUpdateBox\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/grpc/Obsolete/WeakUpdates:\x01*(\x01\x30\x01\x42\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[scalapb_dot_scalapb__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,sequence__and__updates__pb2.DESCRIPTOR,])

_OBSOLETETYPINGTYPE = _descriptor.EnumDescriptor(
  name='ObsoleteTypingType',
  full_name='dialog.ObsoleteTypingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OBSOLETE_TYPINGTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSOLETE_TYPINGTYPE_TEXT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4566,
  serialized_end=4649,
)
_sym_db.RegisterEnumDescriptor(_OBSOLETETYPINGTYPE)

ObsoleteTypingType = enum_type_wrapper.EnumTypeWrapper(_OBSOLETETYPINGTYPE)
OBSOLETE_TYPINGTYPE_UNKNOWN = 0
OBSOLETE_TYPINGTYPE_TEXT = 1


_OBSOLETEPEER_OBSOLETEPEERTYPE = _descriptor.EnumDescriptor(
  name='ObsoletePeerType',
  full_name='dialog.ObsoletePeer.ObsoletePeerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OBSOLETE_PEERTYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSOLETE_PEERTYPE_PRIVATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSOLETE_PEERTYPE_GROUP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSOLETE_PEERTYPE_SIP', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=317,
  serialized_end=453,
)
_sym_db.RegisterEnumDescriptor(_OBSOLETEPEER_OBSOLETEPEERTYPE)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED_OBSOLETEDISPOSALREASON = _descriptor.EnumDescriptor(
  name='ObsoleteDisposalReason',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallDisposed.ObsoleteDisposalReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OBSOLETE_DISPOSAL_REASON_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSOLETE_DISPOSAL_REASON_REJECTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSOLETE_DISPOSAL_REASON_BUSY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSOLETE_DISPOSAL_REASON_ENDED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBSOLETE_DISPOSAL_REASON_ANSWER_TIMEOUT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3167,
  serialized_end=3384,
)
_sym_db.RegisterEnumDescriptor(_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED_OBSOLETEDISPOSALREASON)


_OBSOLETEPEER = _descriptor.Descriptor(
  name='ObsoletePeer',
  full_name='dialog.ObsoletePeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.ObsoletePeer.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='dialog.ObsoletePeer.id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strId', full_name='dialog.ObsoletePeer.strId', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_hash', full_name='dialog.ObsoletePeer.access_hash', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBSOLETEPEER_OBSOLETEPEERTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=453,
)


_OBSOLETEOUTPEER = _descriptor.Descriptor(
  name='ObsoleteOutPeer',
  full_name='dialog.ObsoleteOutPeer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.ObsoleteOutPeer.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accessHash', full_name='dialog.ObsoleteOutPeer.accessHash', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=528,
)


_OBSOLETEPEERSLIST = _descriptor.Descriptor(
  name='ObsoletePeersList',
  full_name='dialog.ObsoletePeersList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peers', full_name='dialog.ObsoletePeersList.peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=586,
)


_OBSOLETEGETDIFFERENCECOMMAND = _descriptor.Descriptor(
  name='ObsoleteGetDifferenceCommand',
  full_name='dialog.ObsoleteGetDifferenceCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ObsoleteGetDifferenceCommand.seq', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ObsoleteGetDifferenceCommand.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configHash', full_name='dialog.ObsoleteGetDifferenceCommand.configHash', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=695,
)


_OBSOLETESEQUPDATEBOX = _descriptor.Descriptor(
  name='ObsoleteSeqUpdateBox',
  full_name='dialog.ObsoleteSeqUpdateBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seq', full_name='dialog.ObsoleteSeqUpdateBox.seq', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='dialog.ObsoleteSeqUpdateBox.state', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obsoleteUpdate', full_name='dialog.ObsoleteSeqUpdateBox.obsoleteUpdate', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='updatebox', full_name='dialog.ObsoleteSeqUpdateBox.updatebox',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=697,
  serialized_end=815,
)


_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATETYPING = _descriptor.Descriptor(
  name='ObsoleteUpdateTyping',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateTyping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateTyping.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateTyping.userId', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateTyping.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isTyping', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateTyping.isTyping', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1836,
  serialized_end=1970,
)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEUSERLASTSEEN = _descriptor.Descriptor(
  name='ObsoleteUpdateUserLastSeen',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateUserLastSeen',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateUserLastSeen.userId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epochMillis', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateUserLastSeen.epochMillis', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceType', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateUserLastSeen.deviceType', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceCategory', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateUserLastSeen.deviceCategory', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isOnline', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateUserLastSeen.isOnline', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1972,
  serialized_end=2099,
)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEGROUPONLINE = _descriptor.Descriptor(
  name='ObsoleteUpdateGroupOnline',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateGroupOnline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateGroupOnline.groupId', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateGroupOnline.count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateGroupOnline.clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2101,
  serialized_end=2175,
)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSMESSAGE = _descriptor.Descriptor(
  name='ObsoleteUpdateEventBusMessage',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='busId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusMessage.busId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='senderId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusMessage.senderId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='senderDeviceId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusMessage.senderDeviceId', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusMessage.message', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2178,
  serialized_end=2341,
)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICECONNECTED = _descriptor.Descriptor(
  name='ObsoleteUpdateEventBusDeviceConnected',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceConnected',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='busId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceConnected.busId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceConnected.userId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceConnected.deviceId', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2343,
  serialized_end=2460,
)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICEDISCONNECTED = _descriptor.Descriptor(
  name='ObsoleteUpdateEventBusDeviceDisconnected',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceDisconnected',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='busId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceDisconnected.busId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceDisconnected.userId', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceDisconnected.deviceId', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2462,
  serialized_end=2582,
)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDISPOSED = _descriptor.Descriptor(
  name='ObsoleteUpdateEventBusDisposed',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDisposed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='busId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDisposed.busId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2584,
  serialized_end=2631,
)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEINCOMINGCALL = _descriptor.Descriptor(
  name='ObsoleteUpdateIncomingCall',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateIncomingCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='callId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateIncomingCall.callId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='busId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateIncomingCall.busId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateIncomingCall.peer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='displayName', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateIncomingCall.displayName', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attemptIndex', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateIncomingCall.attemptIndex', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outPeer', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateIncomingCall.outPeer', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2634,
  serialized_end=2873,
)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLHANDLED = _descriptor.Descriptor(
  name='ObsoleteUpdateCallHandled',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallHandled',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='callId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallHandled.callId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attemptIndex', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallHandled.attemptIndex', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2875,
  serialized_end=2969,
)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED = _descriptor.Descriptor(
  name='ObsoleteUpdateCallDisposed',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallDisposed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='callId', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallDisposed.callId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attemptIndex', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallDisposed.attemptIndex', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallDisposed.reason', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED_OBSOLETEDISPOSALREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2972,
  serialized_end=3384,
)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD = _descriptor.Descriptor(
  name='ObsoleteForceReloadField',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState.ObsoleteForceReloadField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reloadDialogs', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState.ObsoleteForceReloadField.reloadDialogs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reloadContacts', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState.ObsoleteForceReloadField.reloadContacts', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reloadHistory', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState.ObsoleteForceReloadField.reloadHistory', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='field', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState.ObsoleteForceReloadField.field',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3525,
  serialized_end=3711,
)

_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE = _descriptor.Descriptor(
  name='ObsoleteUpdateForceReloadState',
  full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3387,
  serialized_end=3711,
)

_OBSOLETEWEAKUPDATEBOX = _descriptor.Descriptor(
  name='ObsoleteWeakUpdateBox',
  full_name='dialog.ObsoleteWeakUpdateBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='dialog.ObsoleteWeakUpdateBox.date', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typing', full_name='dialog.ObsoleteWeakUpdateBox.typing', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userLastSeen', full_name='dialog.ObsoleteWeakUpdateBox.userLastSeen', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupOnline', full_name='dialog.ObsoleteWeakUpdateBox.groupOnline', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='busMessage', full_name='dialog.ObsoleteWeakUpdateBox.busMessage', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='busDeviceConnected', full_name='dialog.ObsoleteWeakUpdateBox.busDeviceConnected', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='busDeviceDisconnected', full_name='dialog.ObsoleteWeakUpdateBox.busDeviceDisconnected', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='busDisposed', full_name='dialog.ObsoleteWeakUpdateBox.busDisposed', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forceReload', full_name='dialog.ObsoleteWeakUpdateBox.forceReload', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='incomingCall', full_name='dialog.ObsoleteWeakUpdateBox.incomingCall', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callHandled', full_name='dialog.ObsoleteWeakUpdateBox.callHandled', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callDisposed', full_name='dialog.ObsoleteWeakUpdateBox.callDisposed', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_any', full_name='dialog.ObsoleteWeakUpdateBox.update_any', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATETYPING, _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEUSERLASTSEEN, _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEGROUPONLINE, _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSMESSAGE, _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICECONNECTED, _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICEDISCONNECTED, _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDISPOSED, _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEINCOMINGCALL, _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLHANDLED, _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED, _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='updatebox', full_name='dialog.ObsoleteWeakUpdateBox.updatebox',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=818,
  serialized_end=3724,
)


_OBSOLETESERVICEUPDATE = _descriptor.Descriptor(
  name='ObsoleteServiceUpdate',
  full_name='dialog.ObsoleteServiceUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obsoleteUpdate', full_name='dialog.ObsoleteServiceUpdate.obsoleteUpdate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='update', full_name='dialog.ObsoleteServiceUpdate.update',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3726,
  serialized_end=3814,
)


_OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYTYPING = _descriptor.Descriptor(
  name='ObsoleteMyTyping',
  full_name='dialog.ObsoleteWeakUpdateCommand.ObsoleteMyTyping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='dialog.ObsoleteWeakUpdateCommand.ObsoleteMyTyping.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='dialog.ObsoleteWeakUpdateCommand.ObsoleteMyTyping.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='dialog.ObsoleteWeakUpdateCommand.ObsoleteMyTyping.start', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4406,
  serialized_end=4517,
)

_OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYONLINE = _descriptor.Descriptor(
  name='ObsoleteMyOnline',
  full_name='dialog.ObsoleteWeakUpdateCommand.ObsoleteMyOnline',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='online', full_name='dialog.ObsoleteWeakUpdateCommand.ObsoleteMyOnline.online', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4519,
  serialized_end=4553,
)

_OBSOLETEWEAKUPDATECOMMAND = _descriptor.Descriptor(
  name='ObsoleteWeakUpdateCommand',
  full_name='dialog.ObsoleteWeakUpdateCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subscribeToOnlines', full_name='dialog.ObsoleteWeakUpdateCommand.subscribeToOnlines', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsubscribeFromOnlines', full_name='dialog.ObsoleteWeakUpdateCommand.unsubscribeFromOnlines', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dropOnlineSubscriptions', full_name='dialog.ObsoleteWeakUpdateCommand.dropOnlineSubscriptions', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='myTyping', full_name='dialog.ObsoleteWeakUpdateCommand.myTyping', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribeToTypings', full_name='dialog.ObsoleteWeakUpdateCommand.subscribeToTypings', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsubscribeFromTypings', full_name='dialog.ObsoleteWeakUpdateCommand.unsubscribeFromTypings', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dropTypingSubscriptions', full_name='dialog.ObsoleteWeakUpdateCommand.dropTypingSubscriptions', index=6,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subscribeToEventBusUpdates', full_name='dialog.ObsoleteWeakUpdateCommand.subscribeToEventBusUpdates', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='myOnline', full_name='dialog.ObsoleteWeakUpdateCommand.myOnline', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYTYPING, _OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYONLINE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='command', full_name='dialog.ObsoleteWeakUpdateCommand.command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3817,
  serialized_end=4564,
)

_OBSOLETEPEER.fields_by_name['type'].enum_type = _OBSOLETEPEER_OBSOLETEPEERTYPE
_OBSOLETEPEER.fields_by_name['strId'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_OBSOLETEPEER_OBSOLETEPEERTYPE.containing_type = _OBSOLETEPEER
_OBSOLETEOUTPEER.fields_by_name['peer'].message_type = _OBSOLETEPEER
_OBSOLETEPEERSLIST.fields_by_name['peers'].message_type = _OBSOLETEPEER
_OBSOLETEGETDIFFERENCECOMMAND.fields_by_name['seq'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_OBSOLETESEQUPDATEBOX.fields_by_name['obsoleteUpdate'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_OBSOLETESEQUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETESEQUPDATEBOX.fields_by_name['obsoleteUpdate'])
_OBSOLETESEQUPDATEBOX.fields_by_name['obsoleteUpdate'].containing_oneof = _OBSOLETESEQUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATETYPING.fields_by_name['peer'].message_type = _OBSOLETEPEER
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATETYPING.fields_by_name['type'].enum_type = _OBSOLETETYPINGTYPE
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATETYPING.containing_type = _OBSOLETEWEAKUPDATEBOX
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEUSERLASTSEEN.containing_type = _OBSOLETEWEAKUPDATEBOX
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEGROUPONLINE.containing_type = _OBSOLETEWEAKUPDATEBOX
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSMESSAGE.fields_by_name['senderId'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSMESSAGE.fields_by_name['senderDeviceId'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSMESSAGE.containing_type = _OBSOLETEWEAKUPDATEBOX
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICECONNECTED.fields_by_name['userId'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICECONNECTED.containing_type = _OBSOLETEWEAKUPDATEBOX
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICEDISCONNECTED.fields_by_name['userId'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICEDISCONNECTED.containing_type = _OBSOLETEWEAKUPDATEBOX
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDISPOSED.containing_type = _OBSOLETEWEAKUPDATEBOX
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEINCOMINGCALL.fields_by_name['peer'].message_type = _OBSOLETEPEER
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEINCOMINGCALL.fields_by_name['displayName'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEINCOMINGCALL.fields_by_name['attemptIndex'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEINCOMINGCALL.fields_by_name['outPeer'].message_type = _OBSOLETEOUTPEER
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEINCOMINGCALL.containing_type = _OBSOLETEWEAKUPDATEBOX
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLHANDLED.fields_by_name['attemptIndex'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLHANDLED.containing_type = _OBSOLETEWEAKUPDATEBOX
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED.fields_by_name['attemptIndex'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED.fields_by_name['reason'].enum_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED_OBSOLETEDISPOSALREASON
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED.containing_type = _OBSOLETEWEAKUPDATEBOX
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED_OBSOLETEDISPOSALREASON.containing_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.fields_by_name['reloadDialogs'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.fields_by_name['reloadContacts'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.fields_by_name['reloadHistory'].message_type = _OBSOLETEPEERSLIST
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.containing_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.oneofs_by_name['field'].fields.append(
  _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.fields_by_name['reloadDialogs'])
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.fields_by_name['reloadDialogs'].containing_oneof = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.oneofs_by_name['field']
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.oneofs_by_name['field'].fields.append(
  _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.fields_by_name['reloadContacts'])
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.fields_by_name['reloadContacts'].containing_oneof = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.oneofs_by_name['field']
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.oneofs_by_name['field'].fields.append(
  _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.fields_by_name['reloadHistory'])
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.fields_by_name['reloadHistory'].containing_oneof = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD.oneofs_by_name['field']
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE.fields_by_name['fields'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD
_OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE.containing_type = _OBSOLETEWEAKUPDATEBOX
_OBSOLETEWEAKUPDATEBOX.fields_by_name['typing'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATETYPING
_OBSOLETEWEAKUPDATEBOX.fields_by_name['userLastSeen'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEUSERLASTSEEN
_OBSOLETEWEAKUPDATEBOX.fields_by_name['groupOnline'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEGROUPONLINE
_OBSOLETEWEAKUPDATEBOX.fields_by_name['busMessage'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSMESSAGE
_OBSOLETEWEAKUPDATEBOX.fields_by_name['busDeviceConnected'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICECONNECTED
_OBSOLETEWEAKUPDATEBOX.fields_by_name['busDeviceDisconnected'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICEDISCONNECTED
_OBSOLETEWEAKUPDATEBOX.fields_by_name['busDisposed'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDISPOSED
_OBSOLETEWEAKUPDATEBOX.fields_by_name['forceReload'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE
_OBSOLETEWEAKUPDATEBOX.fields_by_name['incomingCall'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEINCOMINGCALL
_OBSOLETEWEAKUPDATEBOX.fields_by_name['callHandled'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLHANDLED
_OBSOLETEWEAKUPDATEBOX.fields_by_name['callDisposed'].message_type = _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED
_OBSOLETEWEAKUPDATEBOX.fields_by_name['update_any'].message_type = sequence__and__updates__pb2._UPDATESEQUPDATE
_OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETEWEAKUPDATEBOX.fields_by_name['typing'])
_OBSOLETEWEAKUPDATEBOX.fields_by_name['typing'].containing_oneof = _OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETEWEAKUPDATEBOX.fields_by_name['userLastSeen'])
_OBSOLETEWEAKUPDATEBOX.fields_by_name['userLastSeen'].containing_oneof = _OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETEWEAKUPDATEBOX.fields_by_name['groupOnline'])
_OBSOLETEWEAKUPDATEBOX.fields_by_name['groupOnline'].containing_oneof = _OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETEWEAKUPDATEBOX.fields_by_name['busMessage'])
_OBSOLETEWEAKUPDATEBOX.fields_by_name['busMessage'].containing_oneof = _OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETEWEAKUPDATEBOX.fields_by_name['busDeviceConnected'])
_OBSOLETEWEAKUPDATEBOX.fields_by_name['busDeviceConnected'].containing_oneof = _OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETEWEAKUPDATEBOX.fields_by_name['busDeviceDisconnected'])
_OBSOLETEWEAKUPDATEBOX.fields_by_name['busDeviceDisconnected'].containing_oneof = _OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETEWEAKUPDATEBOX.fields_by_name['busDisposed'])
_OBSOLETEWEAKUPDATEBOX.fields_by_name['busDisposed'].containing_oneof = _OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETEWEAKUPDATEBOX.fields_by_name['forceReload'])
_OBSOLETEWEAKUPDATEBOX.fields_by_name['forceReload'].containing_oneof = _OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETEWEAKUPDATEBOX.fields_by_name['incomingCall'])
_OBSOLETEWEAKUPDATEBOX.fields_by_name['incomingCall'].containing_oneof = _OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETEWEAKUPDATEBOX.fields_by_name['callHandled'])
_OBSOLETEWEAKUPDATEBOX.fields_by_name['callHandled'].containing_oneof = _OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox'].fields.append(
  _OBSOLETEWEAKUPDATEBOX.fields_by_name['callDisposed'])
_OBSOLETEWEAKUPDATEBOX.fields_by_name['callDisposed'].containing_oneof = _OBSOLETEWEAKUPDATEBOX.oneofs_by_name['updatebox']
_OBSOLETESERVICEUPDATE.fields_by_name['obsoleteUpdate'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_OBSOLETESERVICEUPDATE.oneofs_by_name['update'].fields.append(
  _OBSOLETESERVICEUPDATE.fields_by_name['obsoleteUpdate'])
_OBSOLETESERVICEUPDATE.fields_by_name['obsoleteUpdate'].containing_oneof = _OBSOLETESERVICEUPDATE.oneofs_by_name['update']
_OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYTYPING.fields_by_name['peer'].message_type = _OBSOLETEPEER
_OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYTYPING.fields_by_name['type'].enum_type = _OBSOLETETYPINGTYPE
_OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYTYPING.containing_type = _OBSOLETEWEAKUPDATECOMMAND
_OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYONLINE.containing_type = _OBSOLETEWEAKUPDATECOMMAND
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['subscribeToOnlines'].message_type = _OBSOLETEPEERSLIST
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['unsubscribeFromOnlines'].message_type = _OBSOLETEPEERSLIST
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['dropOnlineSubscriptions'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['myTyping'].message_type = _OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYTYPING
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['subscribeToTypings'].message_type = _OBSOLETEPEERSLIST
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['unsubscribeFromTypings'].message_type = _OBSOLETEPEERSLIST
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['dropTypingSubscriptions'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['subscribeToEventBusUpdates'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['myOnline'].message_type = _OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYONLINE
_OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _OBSOLETEWEAKUPDATECOMMAND.fields_by_name['subscribeToOnlines'])
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['subscribeToOnlines'].containing_oneof = _OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command']
_OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _OBSOLETEWEAKUPDATECOMMAND.fields_by_name['unsubscribeFromOnlines'])
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['unsubscribeFromOnlines'].containing_oneof = _OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command']
_OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _OBSOLETEWEAKUPDATECOMMAND.fields_by_name['dropOnlineSubscriptions'])
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['dropOnlineSubscriptions'].containing_oneof = _OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command']
_OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _OBSOLETEWEAKUPDATECOMMAND.fields_by_name['myTyping'])
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['myTyping'].containing_oneof = _OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command']
_OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _OBSOLETEWEAKUPDATECOMMAND.fields_by_name['subscribeToTypings'])
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['subscribeToTypings'].containing_oneof = _OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command']
_OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _OBSOLETEWEAKUPDATECOMMAND.fields_by_name['unsubscribeFromTypings'])
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['unsubscribeFromTypings'].containing_oneof = _OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command']
_OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _OBSOLETEWEAKUPDATECOMMAND.fields_by_name['dropTypingSubscriptions'])
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['dropTypingSubscriptions'].containing_oneof = _OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command']
_OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _OBSOLETEWEAKUPDATECOMMAND.fields_by_name['subscribeToEventBusUpdates'])
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['subscribeToEventBusUpdates'].containing_oneof = _OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command']
_OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command'].fields.append(
  _OBSOLETEWEAKUPDATECOMMAND.fields_by_name['myOnline'])
_OBSOLETEWEAKUPDATECOMMAND.fields_by_name['myOnline'].containing_oneof = _OBSOLETEWEAKUPDATECOMMAND.oneofs_by_name['command']
DESCRIPTOR.message_types_by_name['ObsoletePeer'] = _OBSOLETEPEER
DESCRIPTOR.message_types_by_name['ObsoleteOutPeer'] = _OBSOLETEOUTPEER
DESCRIPTOR.message_types_by_name['ObsoletePeersList'] = _OBSOLETEPEERSLIST
DESCRIPTOR.message_types_by_name['ObsoleteGetDifferenceCommand'] = _OBSOLETEGETDIFFERENCECOMMAND
DESCRIPTOR.message_types_by_name['ObsoleteSeqUpdateBox'] = _OBSOLETESEQUPDATEBOX
DESCRIPTOR.message_types_by_name['ObsoleteWeakUpdateBox'] = _OBSOLETEWEAKUPDATEBOX
DESCRIPTOR.message_types_by_name['ObsoleteServiceUpdate'] = _OBSOLETESERVICEUPDATE
DESCRIPTOR.message_types_by_name['ObsoleteWeakUpdateCommand'] = _OBSOLETEWEAKUPDATECOMMAND
DESCRIPTOR.enum_types_by_name['ObsoleteTypingType'] = _OBSOLETETYPINGTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ObsoletePeer = _reflection.GeneratedProtocolMessageType('ObsoletePeer', (_message.Message,), {
  'DESCRIPTOR' : _OBSOLETEPEER,
  '__module__' : 'obsolete_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ObsoletePeer)
  })
_sym_db.RegisterMessage(ObsoletePeer)

ObsoleteOutPeer = _reflection.GeneratedProtocolMessageType('ObsoleteOutPeer', (_message.Message,), {
  'DESCRIPTOR' : _OBSOLETEOUTPEER,
  '__module__' : 'obsolete_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ObsoleteOutPeer)
  })
_sym_db.RegisterMessage(ObsoleteOutPeer)

ObsoletePeersList = _reflection.GeneratedProtocolMessageType('ObsoletePeersList', (_message.Message,), {
  'DESCRIPTOR' : _OBSOLETEPEERSLIST,
  '__module__' : 'obsolete_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ObsoletePeersList)
  })
_sym_db.RegisterMessage(ObsoletePeersList)

ObsoleteGetDifferenceCommand = _reflection.GeneratedProtocolMessageType('ObsoleteGetDifferenceCommand', (_message.Message,), {
  'DESCRIPTOR' : _OBSOLETEGETDIFFERENCECOMMAND,
  '__module__' : 'obsolete_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ObsoleteGetDifferenceCommand)
  })
_sym_db.RegisterMessage(ObsoleteGetDifferenceCommand)

ObsoleteSeqUpdateBox = _reflection.GeneratedProtocolMessageType('ObsoleteSeqUpdateBox', (_message.Message,), {
  'DESCRIPTOR' : _OBSOLETESEQUPDATEBOX,
  '__module__' : 'obsolete_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ObsoleteSeqUpdateBox)
  })
_sym_db.RegisterMessage(ObsoleteSeqUpdateBox)

ObsoleteWeakUpdateBox = _reflection.GeneratedProtocolMessageType('ObsoleteWeakUpdateBox', (_message.Message,), {

  'ObsoleteUpdateTyping' : _reflection.GeneratedProtocolMessageType('ObsoleteUpdateTyping', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATETYPING,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateTyping)
    })
  ,

  'ObsoleteUpdateUserLastSeen' : _reflection.GeneratedProtocolMessageType('ObsoleteUpdateUserLastSeen', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEUSERLASTSEEN,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateUserLastSeen)
    })
  ,

  'ObsoleteUpdateGroupOnline' : _reflection.GeneratedProtocolMessageType('ObsoleteUpdateGroupOnline', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEGROUPONLINE,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateGroupOnline)
    })
  ,

  'ObsoleteUpdateEventBusMessage' : _reflection.GeneratedProtocolMessageType('ObsoleteUpdateEventBusMessage', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSMESSAGE,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusMessage)
    })
  ,

  'ObsoleteUpdateEventBusDeviceConnected' : _reflection.GeneratedProtocolMessageType('ObsoleteUpdateEventBusDeviceConnected', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICECONNECTED,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceConnected)
    })
  ,

  'ObsoleteUpdateEventBusDeviceDisconnected' : _reflection.GeneratedProtocolMessageType('ObsoleteUpdateEventBusDeviceDisconnected', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDEVICEDISCONNECTED,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceDisconnected)
    })
  ,

  'ObsoleteUpdateEventBusDisposed' : _reflection.GeneratedProtocolMessageType('ObsoleteUpdateEventBusDisposed', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEEVENTBUSDISPOSED,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDisposed)
    })
  ,

  'ObsoleteUpdateIncomingCall' : _reflection.GeneratedProtocolMessageType('ObsoleteUpdateIncomingCall', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEINCOMINGCALL,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateIncomingCall)
    })
  ,

  'ObsoleteUpdateCallHandled' : _reflection.GeneratedProtocolMessageType('ObsoleteUpdateCallHandled', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLHANDLED,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallHandled)
    })
  ,

  'ObsoleteUpdateCallDisposed' : _reflection.GeneratedProtocolMessageType('ObsoleteUpdateCallDisposed', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATECALLDISPOSED,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateCallDisposed)
    })
  ,

  'ObsoleteUpdateForceReloadState' : _reflection.GeneratedProtocolMessageType('ObsoleteUpdateForceReloadState', (_message.Message,), {

    'ObsoleteForceReloadField' : _reflection.GeneratedProtocolMessageType('ObsoleteForceReloadField', (_message.Message,), {
      'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE_OBSOLETEFORCERELOADFIELD,
      '__module__' : 'obsolete_pb2'
      # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState.ObsoleteForceReloadField)
      })
    ,
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX_OBSOLETEUPDATEFORCERELOADSTATE,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState)
    })
  ,
  'DESCRIPTOR' : _OBSOLETEWEAKUPDATEBOX,
  '__module__' : 'obsolete_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateBox)
  })
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateTyping)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateUserLastSeen)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateGroupOnline)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusMessage)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceConnected)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDeviceDisconnected)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateEventBusDisposed)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateIncomingCall)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateCallHandled)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateCallDisposed)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState)
_sym_db.RegisterMessage(ObsoleteWeakUpdateBox.ObsoleteUpdateForceReloadState.ObsoleteForceReloadField)

ObsoleteServiceUpdate = _reflection.GeneratedProtocolMessageType('ObsoleteServiceUpdate', (_message.Message,), {
  'DESCRIPTOR' : _OBSOLETESERVICEUPDATE,
  '__module__' : 'obsolete_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ObsoleteServiceUpdate)
  })
_sym_db.RegisterMessage(ObsoleteServiceUpdate)

ObsoleteWeakUpdateCommand = _reflection.GeneratedProtocolMessageType('ObsoleteWeakUpdateCommand', (_message.Message,), {

  'ObsoleteMyTyping' : _reflection.GeneratedProtocolMessageType('ObsoleteMyTyping', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYTYPING,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateCommand.ObsoleteMyTyping)
    })
  ,

  'ObsoleteMyOnline' : _reflection.GeneratedProtocolMessageType('ObsoleteMyOnline', (_message.Message,), {
    'DESCRIPTOR' : _OBSOLETEWEAKUPDATECOMMAND_OBSOLETEMYONLINE,
    '__module__' : 'obsolete_pb2'
    # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateCommand.ObsoleteMyOnline)
    })
  ,
  'DESCRIPTOR' : _OBSOLETEWEAKUPDATECOMMAND,
  '__module__' : 'obsolete_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ObsoleteWeakUpdateCommand)
  })
_sym_db.RegisterMessage(ObsoleteWeakUpdateCommand)
_sym_db.RegisterMessage(ObsoleteWeakUpdateCommand.ObsoleteMyTyping)
_sym_db.RegisterMessage(ObsoleteWeakUpdateCommand.ObsoleteMyOnline)


DESCRIPTOR._options = None

_OBSOLETE = _descriptor.ServiceDescriptor(
  name='Obsolete',
  full_name='dialog.Obsolete',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=4652,
  serialized_end=5009,
  methods=[
  _descriptor.MethodDescriptor(
    name='Obsolete',
    full_name='dialog.Obsolete.Obsolete',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=b'\202\323\344\223\002\037\"\032/v1/grpc/Obsolete/Obsolete:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SeqUpdates',
    full_name='dialog.Obsolete.SeqUpdates',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_OBSOLETESEQUPDATEBOX,
    serialized_options=b'\202\323\344\223\002!\"\034/v1/grpc/Obsolete/SeqUpdates:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WeakUpdates',
    full_name='dialog.Obsolete.WeakUpdates',
    index=2,
    containing_service=None,
    input_type=_OBSOLETEWEAKUPDATECOMMAND,
    output_type=_OBSOLETEWEAKUPDATEBOX,
    serialized_options=b'\202\323\344\223\002\"\"\035/v1/grpc/Obsolete/WeakUpdates:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OBSOLETE)

DESCRIPTOR.services_by_name['Obsolete'] = _OBSOLETE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: integrations.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from . import definitions_pb2 as definitions__pb2
from . import peers_pb2 as peers__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='integrations.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12integrations.proto\x12\x06\x64ialog\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x64\x65\x66initions.proto\x1a\x0bpeers.proto\x1a\x15scalapb/scalapb.proto\"q\n\x18ResponseIntegrationToken\x12\x1b\n\x05token\x18\x01 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger\x12\x19\n\x03url\x18\x02 \x01(\tB\x0c\x8a\xea\x30\x08\n\x06\x64\x61nger:\x1d\xe2?\x1a\n\x18im.dlg.grpc.GrpcResponse\"n\n\x1aRequestGetIntegrationToken\x12\x32\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest\"q\n\x1dRequestRevokeIntegrationToken\x12\x32\n\ngroup_peer\x18\x01 \x01(\x0b\x32\x0f.dialog.OutPeerB\r\x8a\xea\x30\t\n\x07visible:\x1c\xe2?\x19\n\x17im.dlg.grpc.GrpcRequest2\xbf\x02\n\x0cIntegrations\x12\x91\x01\n\x13GetIntegrationToken\x12\".dialog.RequestGetIntegrationToken\x1a .dialog.ResponseIntegrationToken\"4\x82\xd3\xe4\x93\x02.\")/v1/grpc/Integrations/GetIntegrationToken:\x01*\x12\x9a\x01\n\x16RevokeIntegrationToken\x12%.dialog.RequestRevokeIntegrationToken\x1a .dialog.ResponseIntegrationToken\"7\x82\xd3\xe4\x93\x02\x31\",/v1/grpc/Integrations/RevokeIntegrationToken:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,definitions__pb2.DESCRIPTOR,peers__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])




_RESPONSEINTEGRATIONTOKEN = _descriptor.Descriptor(
  name='ResponseIntegrationToken',
  full_name='dialog.ResponseIntegrationToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='dialog.ResponseIntegrationToken.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='dialog.ResponseIntegrationToken.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\010\n\006danger', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\032\n\030im.dlg.grpc.GrpcResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=228,
)


_REQUESTGETINTEGRATIONTOKEN = _descriptor.Descriptor(
  name='RequestGetIntegrationToken',
  full_name='dialog.RequestGetIntegrationToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestGetIntegrationToken.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=340,
)


_REQUESTREVOKEINTEGRATIONTOKEN = _descriptor.Descriptor(
  name='RequestRevokeIntegrationToken',
  full_name='dialog.RequestRevokeIntegrationToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='group_peer', full_name='dialog.RequestRevokeIntegrationToken.group_peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\031\n\027im.dlg.grpc.GrpcRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=455,
)

_REQUESTGETINTEGRATIONTOKEN.fields_by_name['group_peer'].message_type = peers__pb2._OUTPEER
_REQUESTREVOKEINTEGRATIONTOKEN.fields_by_name['group_peer'].message_type = peers__pb2._OUTPEER
DESCRIPTOR.message_types_by_name['ResponseIntegrationToken'] = _RESPONSEINTEGRATIONTOKEN
DESCRIPTOR.message_types_by_name['RequestGetIntegrationToken'] = _REQUESTGETINTEGRATIONTOKEN
DESCRIPTOR.message_types_by_name['RequestRevokeIntegrationToken'] = _REQUESTREVOKEINTEGRATIONTOKEN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ResponseIntegrationToken = _reflection.GeneratedProtocolMessageType('ResponseIntegrationToken', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEINTEGRATIONTOKEN,
  '__module__' : 'integrations_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseIntegrationToken)
  })
_sym_db.RegisterMessage(ResponseIntegrationToken)

RequestGetIntegrationToken = _reflection.GeneratedProtocolMessageType('RequestGetIntegrationToken', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETINTEGRATIONTOKEN,
  '__module__' : 'integrations_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetIntegrationToken)
  })
_sym_db.RegisterMessage(RequestGetIntegrationToken)

RequestRevokeIntegrationToken = _reflection.GeneratedProtocolMessageType('RequestRevokeIntegrationToken', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTREVOKEINTEGRATIONTOKEN,
  '__module__' : 'integrations_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestRevokeIntegrationToken)
  })
_sym_db.RegisterMessage(RequestRevokeIntegrationToken)


DESCRIPTOR._options = None
_RESPONSEINTEGRATIONTOKEN.fields_by_name['token']._options = None
_RESPONSEINTEGRATIONTOKEN.fields_by_name['url']._options = None
_RESPONSEINTEGRATIONTOKEN._options = None
_REQUESTGETINTEGRATIONTOKEN.fields_by_name['group_peer']._options = None
_REQUESTGETINTEGRATIONTOKEN._options = None
_REQUESTREVOKEINTEGRATIONTOKEN.fields_by_name['group_peer']._options = None
_REQUESTREVOKEINTEGRATIONTOKEN._options = None

_INTEGRATIONS = _descriptor.ServiceDescriptor(
  name='Integrations',
  full_name='dialog.Integrations',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=458,
  serialized_end=777,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetIntegrationToken',
    full_name='dialog.Integrations.GetIntegrationToken',
    index=0,
    containing_service=None,
    input_type=_REQUESTGETINTEGRATIONTOKEN,
    output_type=_RESPONSEINTEGRATIONTOKEN,
    serialized_options=b'\202\323\344\223\002.\")/v1/grpc/Integrations/GetIntegrationToken:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokeIntegrationToken',
    full_name='dialog.Integrations.RevokeIntegrationToken',
    index=1,
    containing_service=None,
    input_type=_REQUESTREVOKEINTEGRATIONTOKEN,
    output_type=_RESPONSEINTEGRATIONTOKEN,
    serialized_options=b'\202\323\344\223\0021\",/v1/grpc/Integrations/RevokeIntegrationToken:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INTEGRATIONS)

DESCRIPTOR.services_by_name['Integrations'] = _INTEGRATIONS

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import reactions_pb2 as reactions__pb2


class ReactionsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetReactions = channel.unary_unary(
                '/dialog.reactions.Reactions/GetReactions',
                request_serializer=reactions__pb2.GetReactionsRequest.SerializeToString,
                response_deserializer=reactions__pb2.GetReactionsResponse.FromString,
                )
        self.MessageSetReaction = channel.unary_unary(
                '/dialog.reactions.Reactions/MessageSetReaction',
                request_serializer=reactions__pb2.RequestSetMessageReaction.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.MessageRemoveReaction = channel.unary_unary(
                '/dialog.reactions.Reactions/MessageRemoveReaction',
                request_serializer=reactions__pb2.RequestRemoveMessageReaction.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class ReactionsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetReactions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageSetReaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageRemoveReaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReactionsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetReactions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReactions,
                    request_deserializer=reactions__pb2.GetReactionsRequest.FromString,
                    response_serializer=reactions__pb2.GetReactionsResponse.SerializeToString,
            ),
            'MessageSetReaction': grpc.unary_unary_rpc_method_handler(
                    servicer.MessageSetReaction,
                    request_deserializer=reactions__pb2.RequestSetMessageReaction.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'MessageRemoveReaction': grpc.unary_unary_rpc_method_handler(
                    servicer.MessageRemoveReaction,
                    request_deserializer=reactions__pb2.RequestRemoveMessageReaction.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.reactions.Reactions', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Reactions(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetReactions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.reactions.Reactions/GetReactions',
            reactions__pb2.GetReactionsRequest.SerializeToString,
            reactions__pb2.GetReactionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MessageSetReaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.reactions.Reactions/MessageSetReaction',
            reactions__pb2.RequestSetMessageReaction.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MessageRemoveReaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.reactions.Reactions/MessageRemoveReaction',
            reactions__pb2.RequestRemoveMessageReaction.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: permissions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import definitions_pb2 as definitions__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='permissions.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11permissions.proto\x12\x06\x64ialog\x1a\x11\x64\x65\x66initions.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x15scalapb/scalapb.proto\"\x17\n\x15RequestGetPermissions\"\xb0\x01\n\x16ResponseGetPermissions\x12\x36\n\x0bpermissions\x18\x01 \x03(\x0e\x32\x12.dialog.PermissionB\r\x8a\xea\x30\t\n\x07visible\x12@\n\x15\x61ll_known_permissions\x18\x02 \x03(\x0e\x32\x12.dialog.PermissionB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05\x63lock\x18\x03 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible\"o\n\x17UpdatePermissionsChange\x12\x36\n\x0bpermissions\x18\x01 \x03(\x0e\x32\x12.dialog.PermissionB\r\x8a\xea\x30\t\n\x07visible\x12\x1c\n\x05\x63lock\x18\x02 \x01(\x03\x42\r\x8a\xea\x30\t\n\x07visible*v\n\nPermission\x12\x16\n\x12PERMISSION_UNKNOWN\x10\x00\x12\x15\n\x11PERMISSION_SEARCH\x10\x01\x12\x1c\n\x18PERMISSION_CREATE_GROUPS\x10\x02\x12\x1b\n\x17PERMISSION_LEAVE_GROUPS\x10\x03\x32\x8e\x01\n\x0bPermissions\x12\x7f\n\x0eGetPermissions\x12\x1d.dialog.RequestGetPermissions\x1a\x1e.dialog.ResponseGetPermissions\".\x82\xd3\xe4\x93\x02(\"#/v1/grpc/Permissions/GetPermissions:\x01*B\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[definitions__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,scalapb_dot_scalapb__pb2.DESCRIPTOR,])

_PERMISSION = _descriptor.EnumDescriptor(
  name='Permission',
  full_name='dialog.Permission',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_SEARCH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_CREATE_GROUPS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_LEAVE_GROUPS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=418,
  serialized_end=536,
)
_sym_db.RegisterEnumDescriptor(_PERMISSION)

Permission = enum_type_wrapper.EnumTypeWrapper(_PERMISSION)
PERMISSION_UNKNOWN = 0
PERMISSION_SEARCH = 1
PERMISSION_CREATE_GROUPS = 2
PERMISSION_LEAVE_GROUPS = 3



_REQUESTGETPERMISSIONS = _descriptor.Descriptor(
  name='RequestGetPermissions',
  full_name='dialog.RequestGetPermissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=124,
)


_RESPONSEGETPERMISSIONS = _descriptor.Descriptor(
  name='ResponseGetPermissions',
  full_name='dialog.ResponseGetPermissions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.ResponseGetPermissions.permissions', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='all_known_permissions', full_name='dialog.ResponseGetPermissions.all_known_permissions', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.ResponseGetPermissions.clock', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=303,
)


_UPDATEPERMISSIONSCHANGE = _descriptor.Descriptor(
  name='UpdatePermissionsChange',
  full_name='dialog.UpdatePermissionsChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissions', full_name='dialog.UpdatePermissionsChange.permissions', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.UpdatePermissionsChange.clock', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3520\t\n\007visible', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=416,
)

_RESPONSEGETPERMISSIONS.fields_by_name['permissions'].enum_type = _PERMISSION
_RESPONSEGETPERMISSIONS.fields_by_name['all_known_permissions'].enum_type = _PERMISSION
_UPDATEPERMISSIONSCHANGE.fields_by_name['permissions'].enum_type = _PERMISSION
DESCRIPTOR.message_types_by_name['RequestGetPermissions'] = _REQUESTGETPERMISSIONS
DESCRIPTOR.message_types_by_name['ResponseGetPermissions'] = _RESPONSEGETPERMISSIONS
DESCRIPTOR.message_types_by_name['UpdatePermissionsChange'] = _UPDATEPERMISSIONSCHANGE
DESCRIPTOR.enum_types_by_name['Permission'] = _PERMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RequestGetPermissions = _reflection.GeneratedProtocolMessageType('RequestGetPermissions', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTGETPERMISSIONS,
  '__module__' : 'permissions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.RequestGetPermissions)
  })
_sym_db.RegisterMessage(RequestGetPermissions)

ResponseGetPermissions = _reflection.GeneratedProtocolMessageType('ResponseGetPermissions', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEGETPERMISSIONS,
  '__module__' : 'permissions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.ResponseGetPermissions)
  })
_sym_db.RegisterMessage(ResponseGetPermissions)

UpdatePermissionsChange = _reflection.GeneratedProtocolMessageType('UpdatePermissionsChange', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPERMISSIONSCHANGE,
  '__module__' : 'permissions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UpdatePermissionsChange)
  })
_sym_db.RegisterMessage(UpdatePermissionsChange)


DESCRIPTOR._options = None
_RESPONSEGETPERMISSIONS.fields_by_name['permissions']._options = None
_RESPONSEGETPERMISSIONS.fields_by_name['all_known_permissions']._options = None
_RESPONSEGETPERMISSIONS.fields_by_name['clock']._options = None
_UPDATEPERMISSIONSCHANGE.fields_by_name['permissions']._options = None
_UPDATEPERMISSIONSCHANGE.fields_by_name['clock']._options = None

_PERMISSIONS = _descriptor.ServiceDescriptor(
  name='Permissions',
  full_name='dialog.Permissions',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=539,
  serialized_end=681,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetPermissions',
    full_name='dialog.Permissions.GetPermissions',
    index=0,
    containing_service=None,
    input_type=_REQUESTGETPERMISSIONS,
    output_type=_RESPONSEGETPERMISSIONS,
    serialized_options=b'\202\323\344\223\002(\"#/v1/grpc/Permissions/GetPermissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PERMISSIONS)

DESCRIPTOR.services_by_name['Permissions'] = _PERMISSIONS

# @@protoc_insertion_point(module_scope)
